@@ -2,6 +2,7 @@
 # Copyright © 2021 Wacom. All rights reserved.
 """"Utilities"""
 
-__all__ = ['wikipedia']
+__all__ = ['wikipedia', 'rdf']
 
+from knowledge.utils import rdf
 from knowledge.utils import wikipedia
